{
  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs";
    flake-utils.url = "github:numtide/flake-utils";
    nur = {
      url = "git+https://git.jojodev.com/jolheiser/nur";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    tailwind-ctp = {
      url = "git+https://git.jojodev.com/jolheiser/tailwind-ctp";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = {
    self,
    flake-utils,
    nixpkgs,
    nur,
    tailwind-ctp,
  } @ inputs:
    flake-utils.lib.eachDefaultSystem (
      system: let
        pkgs = nixpkgs.legacyPackages.${system};
        nur = inputs.nur.packages.${system};
        tailwind-ctp = inputs.tailwind-ctp.packages.${system}.default;
      in {
        packages.default = pkgs.buildGoModule {
          pname = "jolheiser.com";
          version = "site";
          src = ./.;
          vendorHash = "sha256-Go0L0GFpQj7lQt7z8+iHIyq6bmZkLH/H7iy6vXtYrUg=";
          nativeBuildInputs = [nur.templ tailwind-ctp];
          excludedPackages = ".";
          postBuild = ''
            go generate
            mv dist $out
          '';
        };
        packages.default1 = pkgs.stdenv.mkDerivation {
          pname = "jolheiser.com";
          version = "site";
          src = ./.;
          nativeBuildInputs = with pkgs; [go nur.templ tailwind-ctp];
          buildPhase = ''
            runHook preBuild

            go generate
            mv dist $out

            runHook postBuild
          '';
        };
        devShells.default = pkgs.mkShell {
          nativeBuildInputs = with pkgs; [
            go
            nur.templ
            tailwind-ctp
          ];
        };
      }
    );
}
